@@ -2,8 +2,9 @@ from zebrazoom.code.dataPostProcessing.generateAllTimeTailAngleGraph import gene
 from zebrazoom.code.dataPostProcessing.perBoutOutput import perBoutOutput
 from zebrazoom.code.dataPostProcessing.computeEyesHeadingPlot import computeEyesHeadingPlot
 from zebrazoom.code.dataPostProcessing.tailAnglesHeatmap import tailAnglesHeatMap
+from zebrazoom.code.dataPostProcessing.createPandasDataFrameOfParameters import createPandasDataFrameOfParameters
 
-def dataPostProcessing(outputFolderVideo, superStruct, hyperparameters, videoName):
+def dataPostProcessing(outputFolderVideo, superStruct, hyperparameters, videoName, videoExtension):
 
   if hyperparameters["generateAllTimeTailAngleGraph"]:
     generateAllTimeTailAngleGraph(outputFolderVideo, superStruct, hyperparameters["generateAllTimeTailAngleGraphLineWidth"])  
@@ -15,4 +16,7 @@ def dataPostProcessing(outputFolderVideo, superStruct, hyperparameters, videoNam
     computeEyesHeadingPlot(superStruct, hyperparameters, videoName)
 
   if hyperparameters["tailAnglesHeatMap"]:
-    tailAnglesHeatMap(superStruct, hyperparameters, videoName)
\ No newline at end of file
+    tailAnglesHeatMap(superStruct, hyperparameters, videoName)
+  
+  if hyperparameters["createPandasDataFrameOfParameters"] and hyperparameters["videoFPS"] and hyperparameters["videoPixelSize"]:
+    createPandasDataFrameOfParameters(hyperparameters, videoName, videoExtension)
