@@ -244,14 +244,37 @@ def getGlobalParameters(curbout, fps, pixelSize, frameStepForDistanceCalculation
         TailAngle = [-elem for elem in TailAngle]
       maxTailAngle = max(TailAngle)
       minTailAngle = min(TailAngle)
-      tailAngleSymmetry = - minTailAngle / maxTailAngle
+      tailAngleSymmetry = - minTailAngle / maxTailAngle if maxTailAngle > 0 else 1
       # = 1 if perfect symetry OR if tail angle staying constant and always at 0
       # = 0 if tail beating only on one side, starting from the 0 position
-      # < 0 but > 1 if tail beating only on one side, starting from the side it's beating (not from 0)
+      # < 0 but > -1 if tail beating only on one side, starting from the side it's beating (not from 0)
       listOfParametersCalculated.append(tailAngleSymmetry)
     
     
     
+    elif parameterToCalculate == 'secondBendAmpDividedByFirst':
+      
+      if len(curbout["Bend_Amplitude"]) >= 2 and curbout["Bend_Amplitude"][0]:
+        secondBendAmpDividedByFirst = curbout["Bend_Amplitude"][1] / curbout["Bend_Amplitude"][0]
+      else:
+        secondBendAmpDividedByFirst = float('Nan')
+      listOfParametersCalculated.append(secondBendAmpDividedByFirst)
+    
+    
+    
+    elif parameterToCalculate == 'tailAngleIntegral':
+      
+      if "TailAngle_smoothed" in curbout and len(curbout["TailAngle_smoothed"]):
+        tailAngleIntegral = np.sum([abs(ta) for ta in curbout["TailAngle_smoothed"]]) * (180 / math.pi)
+      else:
+        if "TailAngle_Raw" in curbout and len(curbout["TailAngle_Raw"]):
+          tailAngleIntegral = np.sum([abs(ta) for ta in curbout["TailAngle_Raw"]]) * (180 / math.pi) # Maybe this value should be "reduced" in some way to be consistent with the previous smoothed tail angle
+        else:
+          tailAngleIntegral = float('NaN')
+      listOfParametersCalculated.append(tailAngleIntegral)
+    
+    
+    
     else:
       
       print("The parameter", parameterToCalculate, "is not specified")
